@@ -10,13 +10,13 @@ module Librarian
     let(:action) { described_class.new(env) }
 
     before do
-      env.stub(:specfile_name) { "Specfile" }
+      allow(env).to receive(:specfile_name).and_return("Specfile")
     end
 
     describe "#run" do
 
       context "when the environment does not know its project path" do
-        before { env.stub(:project_path) { nil } }
+        before { allow(env).to receive(:project_path).and_return(nil) }
 
         it "should raise an error describing that the specfile is mising" do
           expect { action.run }.to raise_error(Error, "Cannot find Specfile!")
@@ -24,7 +24,7 @@ module Librarian
       end
 
       context "when the environment knows its project path" do
-        before { env.stub(:project_path) { Dir.tmpdir } }
+        before { allow(env).to receive(:project_path) { Dir.tmpdir } }
 
         it "should not raise an error" do
           expect { action.run }.to_not raise_error
